Well-known extension keys for
ConnectionContext::extensions.
Middleware crates use these constants to read and write data in the context extensions type-map. Using constants avoids typos and documents the inter-middleware contract.
Constants
- EXT_
BRIDGE_ REVERSE - Key for the bridge reverse flag.
- EXT_
COMPRESSION_ STATS - Key for
CompressionStats. - EXT_
SELECTED_ CHANNEL - Key for the selected
ChannelConfigwritten by the model-router middleware. - EXT_
SELECTED_ MAPPING - Key for the selected model mapping written by the model-router middleware.
- EXT_
STATS_ RECORD - Key for the [
StatsRecord] written by the compress middleware.